@@ -1165,6 +1165,7 @@ class SourceFileGenerator : FileGenerator {
 #define _cnm_dump_(to_t, from) do {} while (0)
 #endif
 
+#ifdef DEBUG
 #define _cnm_return_val_if_overflow(to_t,from,val)  G_STMT_START {   \
     gint64  sf = (gint64) from;                                      \
     guint64 uf = (guint64) from;                                     \
@@ -1175,6 +1176,11 @@ class SourceFileGenerator : FileGenerator {
       return (val);                                                  \
     }                                                                \
   } G_STMT_END
+#else /* !def DEBUG */
+/* don't do an overflow checking */
+#define _cnm_return_val_if_overflow(to_t,from,val)  G_STMT_START {   \
+  } G_STMT_END
+#endif /* def DEBUG */
 ");
 	}
 
